==> smtp-0.5.8-039.zip: smtp-0.5.8/rc_strings.h <==
#define SMTP_RC_DEFAULT_LANG  "en"
#define SMTP_RC_UNKNOWN       "Unknown string"
#define SMTP_RC_GATEWAY_DESCR  0
#define SMTP_RC_GATEWAY_PROMPT 1
#define SMTP_RC_REGISTER_MAIN_I 2
#define SMTP_RC_REGISTER_DATA_I  3
#define SMTP_RC_REGISTER_TITLE  4 


#define SMTP_RC_REGISTER_USEGLOBALSETTINGS_LBL  5
#define SMTP_RC_REGISTER_USEGLOBALSETTINGS_DSC  6 
#define SMTP_RC_REGISTER_ATTACHMENTS_LBL  7
#define SMTP_RC_REGISTER_ATTACHMENTS_DSC  8
#define SMTP_RC_REGISTER_ATTACHMENTS_VAL0_LBL  9
#define SMTP_RC_REGISTER_ATTACHMENTS_VAL1_LBL  10
#define SMTP_RC_REGISTER_ATTACHMENTS_VAL2_LBL  11
#define SMTP_RC_REGISTER_PGPJABBERTOMIME_LBL  12
#define SMTP_RC_REGISTER_PGPJABBERTOMIME_DSC  13
#define SMTP_RC_REGISTER_PGPTOJABBERNONMIMETOX_LBL  14
#define SMTP_RC_REGISTER_PGPTOJABBERNONMIMETOX_DSC  15

#define SMTP_RC_REGISTER_SR_MODE_LBL        16
#define SMTP_RC_REGISTER_SR_MODE_VAL0_LBL   17
#define SMTP_RC_REGISTER_SR_MODE_VAL1_LBL   18
#define SMTP_RC_REGISTER_SR_MODE_VAL2_LBL   19
#define SMTP_RC_REGISTER_SR_MODE_VAL3_LBL   20

#define SMTP_RC_REGISTER_SR_SEPARATOR_LBL   26
#define SMTP_RC_REGISTER_SR_TEXT_LBL   27

#define SMTP_RC_REGISTER_SR_HEAD            22
#define SMTP_RC_REGISTER_SR_DSC             21


#define SMTP_RC_REGISTER_J2SHEAD        24
#define SMTP_RC_REGISTER_S2JHEAD        25

#define SMTP_RC_REGISTER_PAID_LBL  28

#define SMTP_RC_VCARD_HISTORY        100
#define SMTP_RC_VCARD_TITLE          101
#define SMTP_RC_VCARD_ROLE           102
#define SMTP_RC_VCARD_BDAY           103

==> smtp-0.5.9-004.zip: smtp-0.5.9/rc_strings.h <==
#define SMTP_RC_DEFAULT_LANG  "en"
#define SMTP_RC_UNKNOWN       "Unknown string"
#define SMTP_RC_GATEWAY_DESCR  0
#define SMTP_RC_GATEWAY_PROMPT 1
#define SMTP_RC_REGISTER_MAIN_I 2
#define SMTP_RC_REGISTER_DATA_I  3
#define SMTP_RC_REGISTER_TITLE  4 


#define SMTP_RC_REGISTER_USEGLOBALSETTINGS_LBL  5
#define SMTP_RC_REGISTER_USEGLOBALSETTINGS_DSC  6 
#define SMTP_RC_REGISTER_ATTACHMENTS_LBL  7
#define SMTP_RC_REGISTER_ATTACHMENTS_DSC  8
#define SMTP_RC_REGISTER_ATTACHMENTS_VAL0_LBL  9
#define SMTP_RC_REGISTER_ATTACHMENTS_VAL1_LBL  10
#define SMTP_RC_REGISTER_ATTACHMENTS_VAL2_LBL  11
#define SMTP_RC_REGISTER_PGPJABBERTOMIME_LBL  12
#define SMTP_RC_REGISTER_PGPJABBERTOMIME_DSC  13
#define SMTP_RC_REGISTER_PGPTOJABBERNONMIMETOX_LBL  14
#define SMTP_RC_REGISTER_PGPTOJABBERNONMIMETOX_DSC  15


#define SMTP_RC_REGISTER_SR_MODE_LBL        16
#define SMTP_RC_REGISTER_SR_MODE_VAL0_LBL   17
#define SMTP_RC_REGISTER_SR_MODE_VAL1_LBL   18
#define SMTP_RC_REGISTER_SR_MODE_VAL2_LBL   19
#define SMTP_RC_REGISTER_SR_MODE_VAL3_LBL   20

#define SMTP_RC_REGISTER_SR_SEPARATOR_LBL   26
#define SMTP_RC_REGISTER_SR_TEXT_LBL   27

#define SMTP_RC_REGISTER_SR_HEAD            22
#define SMTP_RC_REGISTER_SR_DSC             21


#define SMTP_RC_REGISTER_J2SHEAD        24
#define SMTP_RC_REGISTER_S2JHEAD        25

#define SMTP_RC_REGISTER_PAID_LBL  28
#define SMTP_RC_REGISTER_ALLMESSAGESARESPAM_LBL  29
#define SMTP_RC_REGISTER_ALLMESSAGESARESPAM_DSC  30

#define SMTP_RC_VCARD_HISTORY        100
#define SMTP_RC_VCARD_TITLE          101
#define SMTP_RC_VCARD_ROLE           102
#define SMTP_RC_VCARD_BDAY           103


#define SMTP_RC_REGISTER_RT_MODE_LBL        150
#define SMTP_RC_REGISTER_RT_MODE_VAL0_LBL   151
#define SMTP_RC_REGISTER_RT_MODE_VAL1_LBL   152
#define SMTP_RC_REGISTER_RT_NAME_LBL        153
#define SMTP_RC_REGISTER_RT_ADDR_LBL        154
#define SMTP_RC_REGISTER_RT_DSC        155

#define SMTP_XXX_RCPT_NOTFOUND        200
#define SMTP_XXX_MUST_REGISTER        201
#define SMTP_XXX_MESSAGE_SENT         202
#define SMTP_XXX_TIMEOUT_1            203
#define SMTP_XXX_TIMEOUT_0            204

#define SMTP_XXX_SMTP_UNKNOWN_1       205
#define SMTP_XXX_SMTP_UNKNOWN_0       206
#define SMTP_XXX_NOSUBJECT            207
